#!/bin/sh
# ---------------------------------------------------------------------------
# Install wizard hook.
#
# This script is invoked during Unix WASCE+SDK bundle install to accommodate 
# template installs that require *additional* files under WASCE_ROOT or require
# custom processing after the install wizard copies over the server image.  
#
# Template installs that exclusively require customization to files that are 
# already part of the WASCE+SDK bundle, do not have to utilize this script.  Such
# customizations include setting default user ID/password or server ports.
#
# Warning: Files copied using this hook are NOT accounted for by the install
# wizard in its estimate of total install size.  This estimate is presented
# in the pre-install summary dialog.
#
# Example use: If your template install requires the following post-install
# directory structure...
#
# WASCE_ROOT 
#   bin
#   config-store
#   lib
#   myCustomDirTree  <-- Additional files beyond the WASCE install image
#   repository
#   ...
#
# ..this script could be customized to include the following logic...
#
# PGM_DIR=`dirname "$0"`
# WASCE_HOME="$PGM_DIR"/..
# LAUNCHER_HOME="$1"
# 
# cd "$LAUNCHER_HOME"
# cp -r "myCustomDirTree" "$WASCE_HOME"
#
# Parameters passed by the install wizard to this script:
#
# %0 - The filespec of this script.
# %1 - Directory of the install wizard setup launcher.
# %2 - Directory of the install wizard log.
#
# ---------------------------------------------------------------------------
PGM_DIR=`dirname "$0"`
WASCE_HOME="$PGM_DIR"/..
LAUNCHER_HOME="$1"

# LAUNCHER_HOME/_jvm triggers WASCE-private JVM use.  
if [ -r "$LAUNCHER_HOME"/_jvm ]; then
  cd "$LAUNCHER_HOME"
  cp -r "_jvm" "$WASCE_HOME"
fi


           




